@@ -1,9 +1,10 @@
+# $File: //depot/cpan/Module-Install/lib/Module/Install/Makefile/Name.pm $ $Author: autrijus $
+# $Revision: #11 $ $Change: 1645 $ $DateTime: 2003/07/16 01:05:06 $ vim: expandtab shiftwidth=4
+
 package Module::Install::Makefile::Name;
+use Module::Install::Base; @ISA = qw(Module::Install::Base);
 
-use Module::Install::Base;
-@ISA = qw(Module::Install::Base);
-
-$VERSION = '0.66_02';
+$VERSION = '0.01';
 
 use strict;
 
@@ -12,9 +13,7 @@ sub determine_NAME {
     my @modules = glob('*.pm');
 
     require File::Find;
-    File::Find::find( sub {
-        push @modules, $File::Find::name if /\.pm/i;
-    }, 'lib');
+    File::Find::find(sub { push @modules, $File::Find::name if /\.pm/i }, 'lib');
 
     if (@modules == 1) {
         local *MODULE;
@@ -28,10 +27,10 @@ sub determine_NAME {
 
     return if $self->module_name;
 
-    my $name = MM->guess_name or die <<"END_MESSAGE";
+    my $name = MM->guess_name or die <<"END";
 Can't determine a NAME for this distribution.
 Please use the 'name' function in Makefile.PL.
-END_MESSAGE
+END
 
     $name =~ s/-/::/g;
     $self->module_name($name);
